%global __provides_exclude_from %{_libdir}/%{name}/modules/.*\\.so

Name:		irssi
Version:	1.4.3
Release:	%mkrel 1
Summary:	IRC client
License:	GPLv2+
Group:		Networking/IRC
URL:		https://irssi.org/
Source0:	https://github.com/%{name}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
BuildRequires:	pkgconfig(ncursesw)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	perl-devel
BuildRequires:  pkgconfig(libnsl)
# OTR
BuildRequires:	pkgconfig(libotr)
# utf8proc
BuildRequires:	utf8proc-devel
Recommends:	irssi-perl

%description
Irssi is a modular and flexible IRC client for UNIX that has only a text mode
user interface (but as 80-90% of the code isn't text mode specific, other UIs
could be created pretty easily). Also, Irssi isn't really even IRC specific
anymore, there are already working SILC and ICB modules available. Support for
other protocols like ICQ and Jabber could be created some day too.

Irssi is one of the most popular IRC clients at the moment.

%package	devel
Group:		Development/C
Summary:	Development files and headers for the development of irssi applications
Requires:	%{name} = %{version}

%description	devel
Development files and headers for the development of irssi applications.

%package	perl
Group:		Networking/IRC
Summary:	Perl plugin for irssi
Requires:	%{name} = %{version}
Conflicts:	perl-silc

%description	perl
Perl plugin for irssi.

%package	otr
Group:		Networking/IRC
Summary:	LibOTR support for irssi
Requires:	irssi-perl

%description	otr
Off-the-Record (OTR) Messaging support for irssi.

%prep
%setup -q
%autopatch -p1

%build
%configure \
	--disable-static \
	--with-proxy \
	--with-socks \
	--with-bot \
	--with-otr \
	--with-perl=module \
	--with-perl-lib=vendor \
	--enable-true-color
%make_build

%install
%make_install

# Files that should not be installed:
rm -f %{buildroot}%{perl_vendorarch}/perllocal.pod

# Fix rights
find %{buildroot} -name "*.so" -exec chmod 755 {} \;

# Handle docs in files section
rm -rf installed_docs
mv %{buildroot}%{_docdir}/%{name} installed_docs

# We don't want these
find %{buildroot} -name "*.la" -delete

%files
%doc AUTHORS README.md TODO NEWS installed_docs/*
%{_bindir}/*
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/help/
%{_datadir}/%{name}/themes/
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/modules/
%{_libdir}/%{name}/modules/libirc_proxy.so
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_mandir}/man1/%{name}.1*

%files devel
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/irssi-1.pc

%files perl
%{_libdir}/%{name}/modules/libfe_perl.so
%{_libdir}/%{name}/modules/libperl_core.so
%{perl_vendorarch}/Irssi*
%{perl_vendorarch}/auto/*
%{_datadir}/%{name}/scripts/

%files otr
%{_libdir}/%{name}/modules/libotr_core.so


%changelog
* Mon Nov 07 2022 solbu <solbu> 1.4.3-1.mga9
+ Revision: 1904475
- New release: 1.4.3

* Thu Sep 22 2022 solbu <solbu> 1.4.2-1.mga9
+ Revision: 1891368
- New release: 1.4.2

* Sun Jun 12 2022 wally <wally> 1.4.1-1.mga9
+ Revision: 1864012
- new version 1.4.1

* Mon Jun 06 2022 umeabot <umeabot> 1.2.3-5.mga9
+ Revision: 1861501
- Rebuild for Perl 5.36

* Sat Mar 19 2022 umeabot <umeabot> 1.2.3-4.mga9
+ Revision: 1800336
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 1.2.3-3.mga9
+ Revision: 1747659
- rebuild for openssl 3.0.0

* Mon May 24 2021 umeabot <umeabot> 1.2.3-2.mga9
+ Revision: 1726367
- Rebuild for perl 5.34

* Sun Apr 18 2021 daviddavid <daviddavid> 1.2.3-1.mga9
+ Revision: 1716427
- new version: 1.2.3
+ neoclust <neoclust>
- Rebuild against new perl
- Add libnsl-devel as buildrequire

* Wed Jun 17 2020 umeabot <umeabot> 1.2.2-3.mga8
+ Revision: 1594217
- Rebuild for perl 5.32

* Sun Feb 16 2020 umeabot <umeabot> 1.2.2-2.mga8
+ Revision: 1530591
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Sep 03 2019 wally <wally> 1.2.2-1.mga8
+ Revision: 1436739
- new version 1.2.2 to fix CVE-2019-15717 (mga#25388)

* Tue Aug 27 2019 tv <tv> 1.2.1-2.mga8
+ Revision: 1433247
- rebuild with perl-5.30

* Sun Jun 30 2019 wally <wally> 1.2.1-1.mga8
+ Revision: 1416384
- new version 1.2.1 to fix CVE-2019-13045 (mga#25025)

* Sun Feb 17 2019 wally <wally> 1.2.0-2.mga7
+ Revision: 1367924
- enable utf8proc support

* Sun Feb 17 2019 wally <wally> 1.2.0-1.mga7
+ Revision: 1367922
- new version 1.2.0
- build included OTR plug-in as a separate irssi-otr pkg
- fix perl module rights

* Fri Jan 11 2019 wally <wally> 1.1.2-1.mga7
+ Revision: 1354977
- new version 1.1.2 to fix CVE-2019-5882

* Sun Sep 23 2018 umeabot <umeabot> 1.1.1-4.mga7
+ Revision: 1298326
- Mageia 7 Mass Rebuild

* Sun Aug 05 2018 wally <wally> 1.1.1-3.mga7
+ Revision: 1247790
- rebuild for new perl 5.28.0

* Mon May 28 2018 wally <wally> 1.1.1-2.mga7
+ Revision: 1232794
- rebuild for perl 5.26.2

* Sat Feb 17 2018 wally <wally> 1.1.1-1.mga7
+ Revision: 1202077
- new version 1.1.1 to fix CVE-2018-705[0-4] (mga#22609)

* Mon Jan 22 2018 wally <wally> 1.1.0-1.mga7
+ Revision: 1196302
- new version 1.1.0
- update devel pkg summary and description

* Sat Jan 06 2018 wally <wally> 1.0.6-1.mga7
+ Revision: 1190936
- new version 1.0.6

* Sun Oct 22 2017 wally <wally> 1.0.5-1.mga7
+ Revision: 1173082
- new version 1.0.5 to fix CVE-2017-1522[78] and CVE-2017-1572[1-3] (mga#21918)

* Thu Aug 31 2017 pterjan <pterjan> 1.0.4-5.mga7
+ Revision: 1149446
- Rebuild for perl ABI changes

* Sat Jul 22 2017 tv <tv> 1.0.4-4.mga7
+ Revision: 1127831
- rebuild for core/release

* Sat Jul 22 2017 tv <tv> 1.0.4-3.mga7
+ Revision: 1127823
- rebuild for perl 5.26

* Sat Jul 22 2017 neoclust <neoclust> 1.0.4-2.mga7
+ Revision: 1126560
- Rebuild against new Perl 5.26

* Fri Jul 21 2017 wally <wally> 1.0.4-1.mga7
+ Revision: 1125854
- new version 1.0.4 to fix CVE-2017-10965 and CVE-2017-10966 (mga#21199)

* Wed Jun 07 2017 wally <wally> 1.0.3-1.mga6
+ Revision: 1107171
- new version 1.0.3
  * fixes CVE-2017-9468, CVE-2017-9469 (mga#21037)

* Sun Mar 12 2017 wally <wally> 1.0.2-1.mga6
+ Revision: 1092144
- new version 1.0.2

* Mon Feb 06 2017 wally <wally> 1.0.1-1.mga6
+ Revision: 1085007
- new version 1.0.1

* Thu Jan 19 2017 neoclust <neoclust> 1.0.0-2.mga6
+ Revision: 1082460
- Remove Patch0 in description

* Wed Jan 18 2017 wally <wally> 1.0.0-1.mga6
+ Revision: 1082258
- new version 1.0.0
- enable 24bit color support

* Sun Jan 08 2017 wally <wally> 0.8.21-1.mga6
+ Revision: 1080691
- new version 0.8.21 to fix CVE-2017-519[3-6] (mga#20078)
- disable static build and drop .la files
- exclude plugin .so from provides
- clean installed docs

* Wed Nov 16 2016 neoclust <neoclust> 0.8.20-2.mga6
+ Revision: 1067518
- Add P0: Fix CVE-2016-7553

* Fri Sep 23 2016 solbu <solbu> 0.8.20-1.mga6
+ Revision: 1055578
- New version: 0.8.20

* Tue May 10 2016 tv <tv> 0.8.19-1.mga6
+ Revision: 1012145
- new relese
- fix source URL

* Wed Mar 02 2016 umeabot <umeabot> 0.8.17-3.mga6
+ Revision: 983520
- Rebuild for openssl

* Wed Dec 16 2015 wally <wally> 0.8.17-2.mga6
+ Revision: 911057
- irssi-perl: relax perl requires

* Wed Jul 01 2015 solbu <solbu> 0.8.17-1.mga6
+ Revision: 849373
- New version: 0.8.17

* Thu Jun 25 2015 tv <tv> 0.8.16-6.mga6
+ Revision: 843575
- rebuild with soname-ified perl

* Tue Jun 23 2015 sander85 <sander85> 0.8.16-5.mga6
+ Revision: 840594
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 0.8.16-4.mga5
+ Revision: 743600
- Second Mageia 5 Mass Rebuild

* Tue Sep 23 2014 tv <tv> 0.8.16-3.mga5
+ Revision: 722646
- rebuild for new perl

* Tue Sep 16 2014 umeabot <umeabot> 0.8.16-2.mga5
+ Revision: 680569
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sun Aug 03 2014 solbu <solbu> 0.8.16-1.mga5
+ Revision: 659335
- New version

* Tue Jun 03 2014 pterjan <pterjan> 0.8.15-20.mga5
+ Revision: 630781
- Rebuild for perl 5.20

* Mon Oct 21 2013 umeabot <umeabot> 0.8.15-19.mga5
+ Revision: 540745
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 solbu <solbu> 0.8.15-18.mga4
+ Revision: 494247
- Rebuild for ncurses/tinfo split

* Fri Aug 23 2013 tv <tv> 0.8.15-17.mga4
+ Revision: 469925
- rebuild for new perl

* Wed May 29 2013 fwang <fwang> 0.8.15-16.mga4
+ Revision: 430398
- rebuild for new perl

* Sun Mar 17 2013 tv <tv> 0.8.15-15.mga3
+ Revision: 403553
- rebuild for new perl

* Sat Jan 12 2013 umeabot <umeabot> 0.8.15-14.mga3
+ Revision: 354499
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Nov 05 2012 tv <tv> 0.8.15-13.mga3
+ Revision: 314463
- rebuild for new perl

* Thu Aug 23 2012 jquelin <jquelin> 0.8.15-12.mga3
+ Revision: 283288
- perl 5.16.1 rebuild

* Wed May 30 2012 jquelin <jquelin> 0.8.15-11.mga3
+ Revision: 250792
- perl 5.16 rebuild

* Fri Nov 04 2011 jquelin <jquelin> 0.8.15-10.mga2
+ Revision: 162704
- requiring exact perl version, otherwise perl upgrades breaks irssi-perl

* Sun Oct 16 2011 jquelin <jquelin> 0.8.15-9.mga2
+ Revision: 155491
- perl 5.14.2 rebuild

* Tue Jul 12 2011 jquelin <jquelin> 0.8.15-8.mga2
+ Revision: 123106
- perl 5.14.1 rebuild

* Sat Feb 26 2011 jquelin <jquelin> 0.8.15-6.mga2
+ Revision: 60374
- rebuild

* Sun Jan 09 2011 kharec <kharec> 0.8.15-5.mga1
+ Revision: 2025
- imported package irssi

